#!/bin/bash
#
set -x

CONF_DIR=/opt/opengnsys/ogCore/etc/
cd /opt/opengnsys/ogCore/repo/ || exit 


if [ -f /opt/opengnsys/ogCore/installer/.deployed ]; then
    echo "ogCore ya instalado"
    exit 0
fi

while ! docker compose -f $CONF_DIR/docker-compose-deploy.yml ps --format json |jq -r '"\(.Name) \(.State)"' |grep -q 'ogcore-php running'; do
    sleep 2
done

adminuser=$(jq -r '.username' /opt/opengnsys/ogCore/installer/config.json)
adminpass=$(jq -r '.password' /opt/opengnsys/ogCore/installer/config.json)

# Despliega la aplicación
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php composer install
# Genera las claves de JWT
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php php bin/console lexik:jwt:generate-keypair --overwrite
# Crea/actualiza la base de datos
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php php bin/console doctrine:migrations:migrate --no-interaction
# Carga los datos por defecto: usuario
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php php bin/console doctrine:fixtures:load --no-interaction
# Carga los datos por defecto: roles 
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php bin/console app:load-default-user-groups 
# Carga los datos por defecto: comandos
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php php bin/console app:load-default-commands
# Carga los datos por defecto: menú
docker compose -f $CONF_DIR/docker-compose-deploy.yml exec php php bin/console opengnsys:load-default-menu


# Provision user admin
bearer=$(curl -k -X 'POST'   'https://localhost:8443/auth/login'   -H 'accept: application/json'   -H 'Content-Type: application/json'   -d "{ \"username\": \"ogadmin\",  \"password\": \"12345678\" }" | jq .token | sed 's/"//g' )


if [ $adminuser == "ogadmin" ]; then
    echo "Cambiando password a ogadmin no puede ser el usuario administrador"
    ogadmin_uuid=$(curl -q -k -L https://localhost:8443/users/?username=ogadmin -H 'accept: application/json' -H "Authorization: Bearer $bearer" | jq .[0].uuid | sed 's/"//g')
    curl  -k -L -X PUT "https://localhost:8443/users/$ogadmin_uuid/reset-password" -H 'accept: application/ld+json' -H 'Content-Type: application/ld+json' -d "{\"currentPassword\": \"12345678\", \"newPassword\": \"$adminpass\", \"repeatNewPassword\": \"$adminpass\"}" -H "Authorization: Bearer $bearer"
    touch /opt/opengnsys/ogCore/installer/.deployed
    exit 0
fi

curl -k -L --location 'https://localhost:8443/users' \
--header 'Content-Type: application/json' \
--header "Authorization: Bearer $bearer" \
--data "{ \"username\": \"$adminuser\", \"password\": \"$adminpass\", \"roles\": [\"ROLE_SUPER_ADMIN\"] }"


touch /opt/opengnsys/ogCore/installer/.deployed
exit 0 
